#-----------------------------------------------------------------------------
#
# vim: syntax=config
#
# Copyright (C) 2012-2021  Florian Pose <fp@igh.de>
#
# This file is part of the QtPdWidgets library.
#
# The QtPdWidgets library is free software: you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public License as
# published by the Free Software Foundation, either version 3 of the License,
# or (at your option) any later version.
#
# The QtPdWidgets library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser
# General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with the QtPdWidgets Library. If not, see
# <http://www.gnu.org/licenses/>.
#
#-----------------------------------------------------------------------------

TEMPLATE = lib
TARGET = QtPdWidgets2

# good to know: if compiling for android the unix target is selected as well

# On release:
# - Change version in Doxyfile
# - Change version in .spec file
# - Add a NEWS entry
VERSION = 2.0.0

greaterThan(QT_MAJOR_VERSION, 4) {
    CONFIG += debug_and_release
    QT += widgets
    !android {
        QT += designer
    }
    DEFINES += PD_QT5 # needed for moc processing of src/WidgetCollection.h
}
else {
    CONFIG += designer release
}

CONFIG += plugin

QT += network xml svg

greaterThan(QT_MAJOR_VERSION, 4) {
    QT += quick
}

# Path definitions (can be overridden via qmake command-line) ----------------

# Installation prefix (used for header installation only)
isEmpty(PD_INSTALL_PREFIX) {
    PD_INSTALL_PREFIX = $$[QT_INSTALL_PREFIX]
}

# Library installation path
isEmpty(PD_INSTALL_LIBS) {
    PD_INSTALL_LIBS = $$[QT_INSTALL_LIBS]
}

# DLL installation path
isEmpty(PD_INSTALL_BINS) {
    PD_INSTALL_BINS = $$[QT_INSTALL_BINS]
}

# Plugin installation path (i. e. the Qt designer plugin)
isEmpty(PD_INSTALL_PLUGINS) {
    PD_INSTALL_PLUGINS = $$[QT_INSTALL_PLUGINS]
}

# QML installation path
isEmpty(PD_INSTALL_QML) {
    isEmpty($$[QT_INSTALL_QML]) {
        # fallback for older Qt5 versions
        PD_INSTALL_QML = $$[QT_INSTALL_LIBS]/qt5/qml
    }
    else {
        PD_INSTALL_QML = $$[QT_INSTALL_QML]
    }
}

# Compilation flags and directories ------------------------------------------

DEPENDPATH += .
MOC_DIR = .moc
OBJECTS_DIR = .obj

!android {
    QMAKE_CXXFLAGS = -std=gnu++0x
}

CONFIG += c++11

INCLUDEPATH += $${PWD}/$${TARGET}

LIBS += -lpdcom5 -lexpat

win32 {
    LIBS += -lwsock32 # for gethostname in Process.cpp
    CONFIG(debug, debug|release): TARGET = $$join(TARGET,,d)
    CONFIG += dll
}

# Install designer plugin ----------------------------------------------------

target.path = $${PD_INSTALL_PLUGINS}/designer

isEmpty(PD_DISABLE_DESIGNER){
    INSTALLS += target
}

# Install libraries and DLLs -------------------------------------------------

libraries.path = $$PD_INSTALL_LIBS

unix | android { # android just for clarification (see comment above)
    libraries.files = $${OUT_PWD}/lib$${TARGET}.so

    INSTALLS += libraries
}

win32 {
    CONFIG(release, debug|release):libraries.files = \
        "release/lib$${TARGET}.dll.a"
    CONFIG(debug, debug|release):libraries.files = \
        "debug/libd$${TARGET}.dll.a"

    dlls.path = $$PD_INSTALL_BINS
    CONFIG(release, debug|release):dlls.files = \
        "release/$${TARGET}.dll"
    CONFIG(debug, debug|release):dlls.files = \
        "debug/d$${TARGET}.dll"

    INSTALLS += dlls libraries
}

# install headers ------------------------------------------------------------

inst_headers.path = $${PD_INSTALL_PREFIX}/include/$${TARGET}

# place files here which are depended on QWidget
QWIDGETDEPHEADERFILES = \
    $${TARGET}/Bar.h \
    $${TARGET}/CheckBox.h \
    $${TARGET}/ClipImage.h \
    $${TARGET}/CursorEditWidget.h \
    $${TARGET}/Dial.h \
    $${TARGET}/Digital.h \
    $${TARGET}/DoubleSpinBox.h \
    $${TARGET}/Export.h \
    $${TARGET}/Graph.h \
    $${TARGET}/Image.h \
    $${TARGET}/Led.h \
    $${TARGET}/MultiLed.h \
    $${TARGET}/NoPdTouchEdit.h \
    $${TARGET}/PushButton.h \
    $${TARGET}/RadioButton.h \
    $${TARGET}/Rotor.h \
    $${TARGET}/Scale.h \
    $${TARGET}/Settings.h \
    $${TARGET}/SpinBox.h \
    $${TARGET}/Svg.h \
    $${TARGET}/TableView.h \
    $${TARGET}/Tank.h \
    $${TARGET}/Text.h \
    $${TARGET}/Time.h \
    $${TARGET}/TimeScale.h \
    $${TARGET}/TouchEdit.h \
    $${TARGET}/TouchEditDialog.h \
    $${TARGET}/XYGraph.h

inst_headers.files = \
    $${TARGET}/Message.h \
    $${TARGET}/MessageModel.h \
    $${TARGET}/Process.h \
    $${TARGET}/ScalarSubscriber.h \
    $${TARGET}/ScalarVariable.h \
    $${TARGET}/ScalarVariant.h \
    $${TARGET}/TableColumn.h \
    $${TARGET}/TableModel.h \
    $${TARGET}/Translator.h \
    $${TARGET}/ValueRing.h \
    $${TARGET}/VectorVariant.h \
    $${TARGET}/Widget.h

greaterThan(QT_MAJOR_VERSION, 4) {
    inst_headers.files += $${TARGET}/LiveSvg.h
}

!android {
    inst_headers.files += $${QWIDGETDEPHEADERFILES}
}

INSTALLS += inst_headers

# install QML files ----------------------------------------------------------

QML_PATH = $${PD_INSTALL_QML}/de/igh/pd.2

inst_qml.path = $${QML_PATH}
inst_qml.files = \
    qml/de_igh_pdQmlWidgets.pri \
    qml/de_igh_pdQmlWidgets.qrc \
    qml/FontAwesome.otf \
    qml/qmldir \
    qml/Sprintf.js \
    qml/PdBar.qml \
    qml/PdCheckBox.qml \
    qml/PdComboBox.qml \
    qml/PdDigital.qml \
    qml/PdVectorDigital.qml \
    qml/PdLabel.qml \
    qml/PdText.qml \
    qml/PdImage.qml \
    qml/PdLed.qml \
    qml/PdMultiLed.qml \
    qml/PdPushButton.qml \
    qml/PdToolButton.qml \
    qml/PdButton.qml \
    qml/PdSwitch.qml \
    qml/PdSlider.qml \
    qml/PdTimeLabel.qml \
    qml/PdVectorLed.qml \
    qml/PdTouchEdit.qml \
    qml/TouchEdit.qml \
    qml/TouchEditDialog.qml

inst_qml_style.path = $${QML_PATH}/style
inst_qml_style.files = \
    qml/style/qmldir \
    qml/style/Solarized.qml

inst_qml_quick1.path = $${QML_PATH}/quick1
inst_qml_quick1.files = \
    qml/quick1/qmldir \
    qml/quick1/PdLed.qml \
    qml/quick1/PdMultiLed.qml

inst_qml_material.path = $${QML_PATH}/+material
inst_qml_material.files = \
    qml/+material/qmldir \
    qml/+material/PdBar.qml \
    qml/+material/PdToolButton.qml \
    qml/+material/PdTouchEdit.qml \
    qml/+material/TouchEditDialog.qml \

inst_qml_universal.path = $${QML_PATH}/+universal
inst_qml_universal.files = \
    qml/+universal/qmldir \
    qml/+universal/TouchEditDialog.qml

INSTALLS += \
    inst_qml \
    inst_qml_style \
    inst_qml_quick1 \
    inst_qml_material \
    inst_qml_universal

# define headers and sources -------------------------------------------------

HEADERS += \
    $${inst_headers.files}

!android {
    HEADERS += \
        src/BarSection.h \
        src/BarStack.h
}

# place files here which are dependent on QWidget
QWIDGETDEPSOURCES = \
    src/Bar.cpp \
    src/BarSection.cpp \
    src/BarStack.cpp \
    src/CheckBox.cpp \
    src/ClipImage.cpp \
    src/CursorEditWidget.cpp \
    src/Dial.cpp \
    src/Digital.cpp \
    src/DoubleSpinBox.cpp \
    src/Graph.cpp \
    src/Image.cpp \
    src/Led.cpp \
    src/MultiLed.cpp \
    src/NoPdTouchEdit.cpp \
    src/PushButton.cpp \
    src/RadioButton.cpp \
    src/Rotor.cpp \
    src/Scale.cpp \
    src/Settings.cpp \
    src/SpinBox.cpp \
    src/Svg.cpp \
    src/TableView.cpp \
    src/Time.cpp \
    src/TimeScale.cpp \
    src/Tank.cpp \
    src/Text.cpp \
    src/TouchEdit.cpp \
    src/TouchEditDialog.cpp \
    src/XYGraph.cpp

SOURCES += \
    src/Message.cpp \
    src/MessageModel.cpp \
    src/Process.cpp \
    src/ScalarSubscriber.cpp \
    src/ScalarVariant.cpp \
    src/TableColumn.cpp \
    src/TableModel.cpp \
    src/Translator.cpp \
    src/VectorVariant.cpp \
    src/Widget.cpp

greaterThan(QT_MAJOR_VERSION, 4) {
    SOURCES += src/LiveSvg.cpp
}

!android {
    SOURCES += $${QWIDGETDEPSOURCES}
}

!android | isEmpty(PD_DISABLE_PLUGIN) {
    HEADERS += \
        src/Plugin.h \
        src/WidgetCollection.h

    SOURCES += \
        src/Plugin.cpp \
        src/WidgetCollection.cpp
}

RESOURCES = QtPdWidgets.qrc

# translations ---------------------------------------------------------------

TRANSLATIONS = \
    QtPdWidgets_de.ts \
    QtPdWidgets_nl.ts

QM_FILES = $$replace(TRANSLATIONS, "ts$", "qm")

CODECFORTR = UTF-8

# additional files to install ------------------------------------------------

ADDITIONAL_DISTFILES = \
    AUTHORS \
    COPYING \
    COPYING.LESSER \
    Doxyfile \
    NEWS \
    images/* \
    QtPdWidgets.spec \
    README \
    TODO \
    mydist.sh

DISTFILES += $${ADDITIONAL_DISTFILES}

# building documentation -----------------------------------------------------

unix {
    dox.target = dox
    dox.commands = doxygen Doxyfile
    QMAKE_EXTRA_TARGETS += dox

    tags.target = tags
    tags.commands = etags --members $${SOURCES} $${HEADERS}
    QMAKE_EXTRA_TARGETS += tags

    MYDISTFILES = \
        $${ADDITIONAL_DISTFILES} \
        $${HEADERS} \
        $${SOURCES} \
        $${TARGET}.pro \
        $${RESOURCES} \
        $${TRANSLATIONS} \
        $${QM_FILES} \
        test/MainWindow.cpp \
        test/MainWindow.h \
        test/MainWindow.ui \
        test/main.cpp \
        test/test.pro

    mydist.target = mydist
    mydist.commands = ./mydist.sh $${TARGET}-$${VERSION} $${MYDISTFILES}
    QMAKE_EXTRA_TARGETS += mydist
}

#-----------------------------------------------------------------------------
